@@ -112,7 +112,7 @@ class Role:
         self.__member_count = None
 
     def __repr__(self):
-        return f'Role(name={self.name} rank={self.rank})'
+        return f'Role(id={self.id} name={self.name} rank={self.rank})'
 
 
 class Group(api.BaseAuth):
@@ -123,10 +123,10 @@ class Group(api.BaseAuth):
             raise UserWarning('Invalid GroupID or Roblox API down')
         else:
             self.__dict__.update({k.lower(): v for k, v in data.items()})
-            self.roles = sorted([Role(data) for data in self.__dict__.pop('roles')], key=lambda role: role.rank)
             self.owner = User(self.owner['Id'])
             self.__enemies = None
             self.__allies = None
+            self.__roles = None
 
     def __repr__(self):
         return f'Group(id={self.id} name={self.name} owner={self.owner})'
@@ -139,6 +139,13 @@ class Group(api.BaseAuth):
         else:
             return
 
+    @property
+    def roles(self):
+        if not self.__roles:
+            data = requests.get(f'{api.groups}/groups/{self.id}/roles').json()['roles']
+            self.__roles = sorted([Role(role) for role in data], key=lambda role: role.rank)
+        return self.__roles
+
     @property
     def allies(self):
         if type(self.__allies) is not list:
